@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-
 import gi
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk, Gdk, GLib, Gio, GdkPixbuf
@@ -12,32 +11,8 @@ import sys
 import traceback
 import re
 import sqlite3
-import atexit
-import refresh
-from preferences_dialog import PreferencesWindow
-
-GLib.idle_add(refresh.start_backend_refresh)
-
-LOCK_FILE = "/tmp/dnf_app.lock"
-
-# Prevent running twice
-if os.path.exists(LOCK_FILE):
-    print("Application is already running!")
-    exit(1)
-
-# Create lock file
-with open(LOCK_FILE, "w") as f:
-    f.write("running")
-
-# Ensure the lock file is removed when the program exits
-def remove_lock():
-    if os.path.exists(LOCK_FILE):
-        os.remove(LOCK_FILE)
-
-atexit.register(remove_lock)
-
-LOCK_FILE = "/tmp/dnf_app.lock"
 
+# --- Import Classes from other files ---
 from repositories import RepositoriesDialog
 from description import InfoDialog
 
@@ -73,8 +48,6 @@ class PackageApp(Gtk.ApplicationWindow):
         self.upgradable_liststore = Gtk.ListStore(bool, str, str, str, str)
         self.installed_liststore = Gtk.ListStore(bool, str, str, str, str)
         self.available_packages_liststore = Gtk.ListStore(bool, str, str, str, str)
-        self.set_icon_from_file("/usr/share/pixmaps/dnf-package-manager.png")
-
 
         self.upgradable_packages_set = set()
         self.installed_packages_set = set()
@@ -114,7 +87,7 @@ class PackageApp(Gtk.ApplicationWindow):
         menubar.append(preferences_item)
         
         # New History Menu Item
-        history_item = Gtk.MenuItem.new_with_mnemonic("⏳️ _History")
+        history_item = Gtk.MenuItem.new_with_mnemonic("📖 _History")
         history_item.connect("activate", self.on_history_button_clicked)
         history_item.connect("button-press-event", self.on_menu_item_button_press)
         menubar.append(history_item)
@@ -133,7 +106,7 @@ class PackageApp(Gtk.ApplicationWindow):
         self.vbox.pack_start(toolbar, False, False, 0)
         
         self.search_entry = Gtk.SearchEntry()
-        self.search_entry.set_placeholder_text("🔎️ Search packages...")
+        self.search_entry.set_placeholder_text("Search packages...")
         self.search_entry.connect("search-changed", self.on_search_changed)
         
         self.search_entry.set_size_request(150, -1)
@@ -267,26 +240,24 @@ class PackageApp(Gtk.ApplicationWindow):
     class PinDialog(Gtk.Dialog):
         def __init__(self, parent, dnf_cmd, log_func, run_cmd_func):
             super().__init__(
-                title="📍️ Manage Package Pin/Unpin",
+                title="Manage Package Pin/Unpin",
                 parent=parent,
-                flags=0
+                flags=0,
+                buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
             )
-            # Use add_buttons method as recommended
-            self.add_buttons(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
-
             self.dnf_cmd = dnf_cmd
             self.log = log_func
             self.run_command_in_thread = run_cmd_func
             self.parent = parent
             self.connect("response", self.on_response)
             self.set_default_size(600, 400)
-        
+            
             content_area = self.get_content_area()
             self.notebook = Gtk.Notebook()
             content_area.add(self.notebook)
 
             pin_tab = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6, margin=10)
-            self.notebook.append_page(pin_tab, Gtk.Label(label="📍️ Pin a Package"))
+            self.notebook.append_page(pin_tab, Gtk.Label(label="Pin a Package"))
 
             pin_search_entry = Gtk.SearchEntry()
             pin_search_entry.set_placeholder_text("Search installed packages...")
@@ -308,7 +279,7 @@ class PackageApp(Gtk.ApplicationWindow):
             scrolled_window_pin.add(self.pin_treeview)
             pin_tab.pack_start(scrolled_window_pin, True, True, 0)
             
-            pin_button = Gtk.Button.new_with_label("📍️ Pin Selected Package")
+            pin_button = Gtk.Button.new_with_label("Pin Selected Package")
             pin_button.connect("clicked", self.on_pin_clicked)
             pin_tab.pack_end(pin_button, False, False, 0)
             self.pin_selection = self.pin_treeview.get_selection()
@@ -317,7 +288,7 @@ class PackageApp(Gtk.ApplicationWindow):
             self.populate_installed_packages()
 
             unpin_tab = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6, margin=10)
-            self.notebook.append_page(unpin_tab, Gtk.Label(label="📍️ Unpin Packages"))
+            self.notebook.append_page(unpin_tab, Gtk.Label(label="Unpin Packages"))
 
             self.unpin_liststore = Gtk.ListStore(str)
             self.unpin_treeview = Gtk.TreeView(model=self.unpin_liststore)
@@ -438,8 +409,84 @@ class PackageApp(Gtk.ApplicationWindow):
                     use_pkexec=True
                 )
     
+    # --- END OF PinDialog CLASS ---
+    # --- Updated PreferencesWindow Class (nested) ---
+    class PreferencesWindow(Gtk.Dialog):
+        def __init__(self, parent, preferences):
+            super().__init__(
+                title="Preferences",
+                parent=parent,
+                flags=0,
+                buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                         Gtk.STOCK_APPLY, Gtk.ResponseType.APPLY,
+                         Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
+            )
+            self.parent = parent
+            self.preferences = preferences.copy()
+            self.set_default_size(400, 300)
+
+            grid = Gtk.Grid()
+            grid.set_column_spacing(10)
+            grid.set_row_spacing(10)
+            grid.set_border_width(12)
+            self.get_content_area().add(grid)
+
+            row = 0
+
+            general_frame = Gtk.Frame(label="General Options")
+            grid.attach(general_frame, 0, row, 2, 1)
+            general_grid = Gtk.Grid()
+            general_grid.set_column_spacing(10)
+            general_grid.set_row_spacing(10)
+            general_grid.set_border_width(12)
+            general_frame.add(general_grid)
+
+            self.disable_confirm_check = Gtk.CheckButton.new_with_label("Disable confirmation dialogs for actions")
+            self.disable_confirm_check.set_active(self.preferences.get("disable_confirm", False))
+            general_grid.attach(self.disable_confirm_check, 0, 0, 2, 1)
+
+            self.clear_cache_check = Gtk.CheckButton.new_with_label("Clean DNF cache after successful action")
+            self.clear_cache_check.set_active(self.preferences.get("clear_cache", False))
+            general_grid.attach(self.clear_cache_check, 0, 1, 2, 1)
+            
+            row += 1
+
+            history_frame = Gtk.Frame(label="History Options")
+            grid.attach(history_frame, 0, row, 2, 1)
+            history_grid = Gtk.Grid()
+            history_grid.set_column_spacing(10)
+            history_grid.set_row_spacing(10)
+            history_grid.set_border_width(12)
+            history_frame.add(history_grid)
+
+            history_size_label = Gtk.Label(label="History Size:", xalign=0)
+            history_grid.attach(history_size_label, 0, 0, 1, 1)
+            
+            self.history_size_adj = Gtk.Adjustment(
+                value=self.preferences.get("history_size", 50),
+                lower=1,
+                upper=1000,
+                step_increment=1,
+                page_increment=10
+            )
+            self.history_size_spin = Gtk.SpinButton(
+                adjustment=self.history_size_adj,
+                climb_rate=0,
+                digits=0
+            )
+            history_grid.attach(self.history_size_spin, 1, 0, 1, 1)
+
+            self.connect("response", self.on_response)
+            self.show_all()
+
         def on_response(self, dialog, response_id):
             if response_id in (Gtk.ResponseType.APPLY, Gtk.ResponseType.CLOSE):
+                self.preferences["disable_confirm"] = self.disable_confirm_check.get_active()
+                self.preferences["clear_cache"] = self.clear_cache_check.get_active()
+                self.preferences["history_size"] = self.history_size_spin.get_value_as_int()
+
+                self.parent.preferences.update(self.preferences)
+                self.parent.save_preferences(self.parent.preferences)
 
                 if response_id == Gtk.ResponseType.APPLY:
                     self.parent.log("Preferences applied.")
@@ -453,7 +500,7 @@ class PackageApp(Gtk.ApplicationWindow):
     class HistoryDialog(Gtk.Dialog):
         def __init__(self, parent):
             super().__init__(
-                title="⏳️ DNF Transaction History",
+                title="DNF Transaction History",
                 parent=parent,
                 flags=0
             )
@@ -463,7 +510,7 @@ class PackageApp(Gtk.ApplicationWindow):
             self.add_buttons(
                 Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE
             )
-        
+            
             content_area = self.get_content_area()
             vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6, margin=10)
             content_area.add(vbox)
@@ -477,7 +524,7 @@ class PackageApp(Gtk.ApplicationWindow):
                 renderer = Gtk.CellRendererText()
                 column = Gtk.TreeViewColumn(col_name, renderer, text=i)
                 self.treeview.append_column(column)
-        
+            
             scrolled_window = Gtk.ScrolledWindow()
             scrolled_window.set_shadow_type(Gtk.ShadowType.IN)
             scrolled_window.add(self.treeview)
@@ -490,15 +537,15 @@ class PackageApp(Gtk.ApplicationWindow):
             details_scroll = Gtk.ScrolledWindow()
             details_scroll.set_size_request(-1, 200)
             details_scroll.add(self.details_textview)
-            vbox.pack_start(details_scroll, True, True, 0)
-        
+            vbox.pack_start(details_scroll, False, False, 0)
+            
             action_box = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL, spacing=6, margin_top=6)
             vbox.pack_start(action_box, False, False, 0)
 
             self.delete_history_button = Gtk.Button.new_with_label("⚠️ Delete All History")
             self.delete_history_button.connect("clicked", self.on_delete_history_clicked)
             action_box.pack_end(self.delete_history_button, False, False, 0)
-        
+            
             self.revert_button = Gtk.Button.new_with_label("⏪ Revert Transaction")
             self.revert_button.connect("clicked", self.on_revert_clicked)
             action_box.pack_start(self.revert_button, False, False, 0)
@@ -511,128 +558,14 @@ class PackageApp(Gtk.ApplicationWindow):
 
             self.treeview.get_selection().connect("changed", self.on_selection_changed)
             self.connect("response", self.on_dialog_response)
-        
+            
             self.populate_history()
             self.show_all()
 
-        def on_delete_history_clicked(self, widget):
-            if not self.parent.preferences.get("disable_confirm", False):
-                dialog = Gtk.MessageDialog(
-                    parent=self,
-                    flags=0,
-                    message_type=Gtk.MessageType.WARNING,
-                    buttons=Gtk.ButtonsType.OK_CANCEL,
-                    text="Are you sure you want to delete the entire history?"
-                )
-                dialog.format_secondary_text("This action is irreversible and will permanently remove all DNF transaction records. Proceed with caution!")
-                response = dialog.run()
-                dialog.destroy()
-            
-                if response != Gtk.ResponseType.OK:
-                    return
-    
-            HISTORY_PATH = "/usr/lib/sysimage/libdnf5/transaction_history.sqlite"
-            if not os.path.exists(HISTORY_PATH):
-                self.parent.log(f"Error: History database not found at {HISTORY_PATH}.")
-                return
-            
-            try:
-                conn = sqlite3.connect(HISTORY_PATH)
-                cursor = conn.cursor()
-                cursor.execute("DELETE FROM trans")
-                conn.commit()
-                conn.close()
-                self.parent.log("DNF transaction history deleted successfully.")
-                self.populate_history()
-            except sqlite3.Error as e:
-                self.parent.log(f"Error deleting history: {e}")
-
-        def on_revert_clicked(self, widget):
-            selection = self.treeview.get_selection()
-            model, treeiter = selection.get_selected()
-            if treeiter:
-                trans_id = model[treeiter][0]
-            
-                if not self.parent.preferences.get("disable_confirm", False):
-                    dialog = Gtk.MessageDialog(
-                        parent=self,
-                        flags=0,
-                        message_type=Gtk.MessageType.QUESTION,
-                        buttons=Gtk.ButtonsType.OK_CANCEL,
-                        text=f"Are you sure you want to revert transaction ID {trans_id}?"
-                    )
-                    dialog.format_secondary_text("This will undo all package changes made in this transaction.")
-                    response = dialog.run()
-                    dialog.destroy()
-                
-                    if response != Gtk.ResponseType.OK:
-                        return
-    
-                self.parent.log(f"Reverting transaction ID {trans_id}...")
-                self.parent.run_command_in_thread(
-                    [self.parent.dnf_cmd, "history", "undo", str(trans_id)],
-                    f"Transaction {trans_id} reverted successfully.",
-                    f"Failed to revert transaction {trans_id}.",
-                    on_finish_callback=lambda s,e,r: self.populate_history(),
-                    use_pkexec=True
-                )
-
-        def on_save_clicked(self, widget):
-            text_buffer = self.details_textview.get_buffer()
-            text_to_save = text_buffer.get_text(
-                text_buffer.get_start_iter(),
-                text_buffer.get_end_iter(),
-                False
-            )
-
-            if not text_to_save.strip():
-                dialog = Gtk.MessageDialog(
-                    parent=self,
-                    flags=0,
-                    message_type=Gtk.MessageType.INFO,
-                    buttons=Gtk.ButtonsType.OK,
-                    text="Nothing to save."
-                )
-                dialog.format_secondary_text("Please select a transaction to display its details before saving.")
-                dialog.run()
-                dialog.destroy()
-                return
-
-            dialog = Gtk.FileChooserDialog(
-                title="Save Transaction Details",
-                parent=self,
-                action=Gtk.FileChooserAction.SAVE,
-                buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
-            )
-            dialog.set_do_overwrite_confirmation(True)
-
-            response = dialog.run()
-            if response == Gtk.ResponseType.OK:
-                filename = dialog.get_filename()
-                if filename:
-                    try:
-                        with open(filename, 'w') as f:
-                            f.write(text_to_save)
-                        self.parent.log(f"Successfully saved details to {filename}")
-                    except Exception as e:
-                        self.parent.log(f"Failed to save file: {e}")
-                        error_dialog = Gtk.MessageDialog(
-                            parent=self,
-                            flags=0,
-                            message_type=Gtk.MessageType.ERROR,
-                            buttons=Gtk.ButtonsType.OK,
-                            text="Failed to save file."
-                        )
-                        error_dialog.format_secondary_text(f"An error occurred: {e}")
-                        error_dialog.run()
-                        error_dialog.destroy()
-        
-            dialog.destroy()
-
         def on_dialog_response(self, dialog, response_id):
             if response_id == Gtk.ResponseType.CLOSE:
                 dialog.destroy()
-            
+                
         def on_selection_changed(self, selection):
             model, treeiter = selection.get_selected()
             if treeiter:
@@ -649,11 +582,11 @@ class PackageApp(Gtk.ApplicationWindow):
                 self.revert_button.set_sensitive(False)
                 self.save_button.set_sensitive(False)
                 self.details_textview.get_buffer().set_text("")
-            
+                
         def _on_details_complete(self, stdout, stderr, returncode):
             buffer = self.details_textview.get_buffer()
             buffer.set_text("")
-        
+            
             if returncode == 0:
                 if stdout.strip():
                     buffer.set_text(stdout.strip())
@@ -677,11 +610,11 @@ class PackageApp(Gtk.ApplicationWindow):
                 conn = sqlite3.connect(HISTORY_PATH)
                 cursor = conn.cursor()
                 cursor.execute("SELECT id, description, dt_begin FROM trans ORDER BY id DESC")
-            
+                
                 rows = cursor.fetchall()
                 if not rows:
                     self.parent.log("No transaction history found.")
-            
+                
                 for row in rows:
                     trans_id = row[0]
                     description = row[1]
@@ -692,35 +625,32 @@ class PackageApp(Gtk.ApplicationWindow):
                     time_str = start_datetime.strftime("%H:%M:%S")
 
                     self.liststore.append([trans_id, date_str, time_str, description])
-            
+                
                 conn.close()
                 self.parent.log(f"Loaded {len(rows)} history entries.")
 
             except sqlite3.Error as e:
                 self.parent.log(f"SQLite error: {e}")
                 
-    def on_delete_history_clicked(self, widget):
-            if not self.parent.preferences.get("disable_confirm", False):
-                dialog = Gtk.MessageDialog(
-                    parent=self,
-                    flags=0,
-                    message_type=Gtk.MessageType.WARNING,
-                    buttons=Gtk.ButtonsType.OK_CANCEL,
-                    text="Are you sure you want to delete the entire history?"
-                )
-                dialog.format_secondary_text("This action is irreversible and will permanently remove all DNF transaction records. Proceed with caution!")
-                response = dialog.run()
-                dialog.destroy()
+        def on_delete_history_clicked(self, widget):
+            dialog = Gtk.MessageDialog(
+                parent=self,
+                flags=0,
+                message_type=Gtk.MessageType.WARNING,
+                buttons=Gtk.ButtonsType.OK_CANCEL,
+                text="Are you sure you want to delete the entire history?"
+            )
+            dialog.format_secondary_text("This action is irreversible and will permanently remove all DNF transaction records. Proceed with caution!")
+            response = dialog.run()
+            dialog.destroy()
             
-                if response != Gtk.ResponseType.OK:
+            if response == Gtk.ResponseType.OK:
+                HISTORY_PATH = "/usr/lib/sysimage/libdnf5/transaction_history.sqlite"
+                if not os.path.exists(HISTORY_PATH):
+                    self.parent.log(f"Error: History database not found at {HISTORY_PATH}.")
                     return
-    
-            HISTORY_PATH = "/usr/lib/sysimage/libdnf5/transaction_history.sqlite"
-            if not os.path.exists(HISTORY_PATH):
-                self.parent.log(f"Error: History database not found at {HISTORY_PATH}.")
-                return
-            
-            try:
+
+                try:
                     conn = sqlite3.connect(HISTORY_PATH)
                     cursor = conn.cursor()
                     cursor.execute("DELETE FROM trans")
@@ -728,91 +658,56 @@ class PackageApp(Gtk.ApplicationWindow):
                     conn.close()
                     self.parent.log("DNF transaction history deleted successfully.")
                     self.populate_history()
-            except sqlite3.Error as e:
-                    self.parent.log(f"Error deleting history: {e}")                
-
-    def on_revert_clicked(self, widget):
+                except sqlite3.Error as e:
+                    self.parent.log(f"Error deleting history: {e}")
+                    
+        def on_revert_clicked(self, widget):
             selection = self.treeview.get_selection()
             model, treeiter = selection.get_selected()
             if treeiter:
                 trans_id = model[treeiter][0]
-            
-                # Check the preference before showing the dialog
-                if not self.parent.preferences.get("disable_confirm", False):
-                    dialog = Gtk.MessageDialog(
-                        parent=self,
-                        flags=0,
-                        message_type=Gtk.MessageType.QUESTION,
-                        buttons=Gtk.ButtonsType.OK_CANCEL,
-                        text=f"Are you sure you want to revert transaction ID {trans_id}?"
-                    )
-                    dialog.format_secondary_text("This will undo all package changes made in this transaction.")
-                    response = dialog.run()
-                    dialog.destroy()
-                
-                    if response != Gtk.ResponseType.OK:
-                        return # Exit if the user cancels
-    
-                self.parent.log(f"Reverting transaction ID {trans_id}...")
-                self.parent.run_command_in_thread(
-                    [self.parent.dnf_cmd, "history", "undo", str(trans_id)],
-                    f"Transaction {trans_id} reverted successfully.",
-                    f"Failed to revert transaction {trans_id}.",
-                    on_finish_callback=lambda s,e,r: self.populate_history(),
-                    use_pkexec=True
+                dialog = Gtk.MessageDialog(
+                    parent=self,
+                    flags=0,
+                    message_type=Gtk.MessageType.QUESTION,
+                    buttons=Gtk.ButtonsType.OK_CANCEL,
+                    text=f"Are you sure you want to revert transaction ID {trans_id}?"
                 )
-
-    def on_save_clicked(self, widget):
-        text_buffer = self.details_textview.get_buffer()
-        text_to_save = text_buffer.get_text(
-            text_buffer.get_start_iter(),
-            text_buffer.get_end_iter(),
-            False
-        )
-
-        if not text_to_save.strip():
-            dialog = Gtk.MessageDialog(
-                parent=self,
-                flags=0,
-                message_type=Gtk.MessageType.INFO,
-                buttons=Gtk.ButtonsType.OK,
-                text="Nothing to save."
-            )
-            dialog.format_secondary_text("Please select a transaction to display its details before saving.")
-            dialog.run()
-            dialog.destroy()
-            return
-
-        dialog = Gtk.FileChooserDialog(
-            title="Save Transaction Details",
-            parent=self,
-            action=Gtk.FileChooserAction.SAVE,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_SAVE, Gtk.ResponseType.OK)
-        )
-        dialog.set_do_overwrite_confirmation(True)
-
-        response = dialog.run()
-        if response == Gtk.ResponseType.OK:
-            filename = dialog.get_filename()
-            if filename:
-                try:
-                    with open(filename, 'w') as f:
-                        f.write(text_to_save)
-                    self.parent.log(f"Successfully saved details to {filename}")
-                except Exception as e:
-                    self.parent.log(f"Failed to save file: {e}")
-                    error_dialog = Gtk.MessageDialog(
-                        parent=self,
-                        flags=0,
-                        message_type=Gtk.MessageType.ERROR,
-                        buttons=Gtk.ButtonsType.OK,
-                        text="Failed to save file."
+                dialog.format_secondary_text("This will undo all package changes made in this transaction.")
+                response = dialog.run()
+                dialog.destroy()
+                
+                if response == Gtk.ResponseType.OK:
+                    self.parent.log(f"Reverting transaction ID {trans_id}...")
+                    self.parent.run_command_in_thread(
+                        [self.parent.dnf_cmd, "history", "undo", str(trans_id)],
+                        f"Transaction {trans_id} reverted successfully.",
+                        f"Failed to revert transaction {trans_id}.",
+                        on_finish_callback=lambda s,e,r: self.populate_history(),
+                        use_pkexec=True
                     )
-                    error_dialog.format_secondary_text(f"An error occurred: {e}")
-                    error_dialog.run()
-                    error_dialog.destroy()
-    
-            dialog.destroy()
+
+        def on_save_clicked(self, widget):
+            text_buffer = self.details_textview.get_buffer()
+            text_to_save = text_buffer.get_text(
+                text_buffer.get_start_iter(),
+                text_buffer.get_end_iter(),
+                False
+            )
+
+            if not text_to_save.strip():
+                dialog = Gtk.MessageDialog(
+                    parent=self,
+                    flags=0,
+                    message_type=Gtk.MessageType.INFO,
+                    buttons=Gtk.ButtonsType.OK,
+                    text="Nothing to save."
+                )
+                dialog.format_secondary_text("Please select a transaction to display its details before saving.")
+                dialog.run()
+                dialog.destroy()
+                return
+
             dialog = Gtk.FileChooserDialog(
                 title="Save Transaction Details",
                 parent=self,
@@ -986,54 +881,36 @@ class PackageApp(Gtk.ApplicationWindow):
         """Parses the output of 'dnf repoquery' and populates a ListStore."""
         if list_type is None:
             return
- 
-        srpm_path_prefix = "/mnt/repo/srpms/SRPMS.pclos"  # skip SRPMs from this folder
-            # Skip SRPMs entirely (from repo or source packages)
-
+            
         for line in stdout.splitlines():
             line = line.strip()
             if not line:
                 continue
-
             parts = line.split(':', 3)
-            if len(parts) != 4:
-                continue
-
-            name = parts[0].strip()
-            summary = parts[1].strip()
-            repo = parts[2].strip()
-            version_raw = parts[3].strip()
- 
-            if repo.lower().startswith("srpms") or name.endswith(".src") or name.endswith(".srpm"):
-                continue
-            # Skip SRPMs
-            if name.endswith(".src") or name.endswith(".srpm") or name.startswith(srpm_path_prefix):
-                continue
-
-            version = re.sub(r'pclos20\d{2}\.x86_64|pclos20\d{2}\.i686|pclos20\d{2}', '', version_raw)
-            version = version.rstrip('.-_')
-
-            # Determine display name and status
-            display_name = name
-            if list_type == "upgradable":
-                status = "Upgradable"
-                self.upgradable_packages_set.add(name)
-            elif list_type == "installed":
-                if name not in self.upgradable_packages_set:
-                    status = "Installed"
-                    self.installed_packages_set.add(name)
+            if len(parts) == 4:
+                name = parts[0].strip()
+                summary = parts[1].strip()
+                repo = parts[2].strip()
+                version_raw = parts[3].strip()
+                
+                version = re.sub(r'pclos20\d{2}\.x86_64|pclos20\d{2}\.i686|pclos20\d{2}', '', version_raw)
+                version = version.rstrip('.-_')
+                
+                if list_type == "upgradable":
+                    status = "Upgradable"
+                    self.upgradable_packages_set.add(name)
+                    liststore.append([False, name, version, summary, status])
+                elif list_type == "installed":
+                    if name not in self.upgradable_packages_set:
+                        status = "Installed"
+                        self.installed_packages_set.add(name)
+                        liststore.append([False, name, version, summary, status])
+                elif list_type == "available":
+                    if name not in self.upgradable_packages_set and name not in self.installed_packages_set:
+                        status = "Available"
+                        liststore.append([False, name, version, summary, status])
                 else:
-                    continue  # skip duplicates
-            elif list_type == "available":
-                if name not in self.upgradable_packages_set and name not in self.installed_packages_set:
-                    status = "Available"
-                else:
-                    continue  # skip duplicates
-            else:
-                status = "Unknown"
-
-            # Append to the ListStore
-            liststore.append([False, display_name, version, summary, status])
+                    status = "Unknown"
 
     def _parse_check_update_output(self, liststore, stdout):
         """Parses the output of 'dnf check-update' for upgradable packages."""
@@ -1262,40 +1139,13 @@ class PackageApp(Gtk.ApplicationWindow):
             return
 
         dialog = Gtk.MessageDialog(
-            transient_for=self,
-            modal=True,
+            parent=self,
+            flags=0,
             message_type=Gtk.MessageType.QUESTION,
             buttons=Gtk.ButtonsType.OK_CANCEL,
-            text=f"📦️ Are you sure you want to {action} these packages?"
+            text=f"Are you sure you want to {action} these packages?"
         )
-
-        # Scrollable area
-        scrolled = Gtk.ScrolledWindow()
-        scrolled.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
-        scrolled.set_min_content_height(200)
-        scrolled.set_min_content_width(400)
-
-        # Box to hold the label and force top alignment
-        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
-        vbox.set_halign(Gtk.Align.FILL)
-        vbox.set_valign(Gtk.Align.START)  # top align
-
-        label = Gtk.Label(label="\n".join(packages))
-        label.set_xalign(0)       # left align
-        label.set_selectable(True)  # allow copy/paste
-        label.set_margin_top(5)
-        label.set_margin_bottom(5)
-        label.set_margin_left(10)
-        label.set_margin_right(10)
-
-        vbox.pack_start(label, False, False, 0)
-        scrolled.add(vbox)
-
-        # Add scrolled window to the dialog
-        content_area = dialog.get_content_area()
-        content_area.pack_start(scrolled, True, True, 0)
-        content_area.show_all()
-
+        dialog.format_secondary_text("\n".join(packages))
         response = dialog.run()
         dialog.destroy()
 
@@ -1334,61 +1184,45 @@ class PackageApp(Gtk.ApplicationWindow):
         thread.start()
 
     def _run_transaction_in_thread(self, command_parts):
-            try:
-                full_command = ["pkexec"] + command_parts
-                GLib.idle_add(self.log, f"Executing command: {' '.join(full_command)}")
-                GLib.idle_add(self.progress_dialog.status_label.set_text, "Starting transaction...")
+        try:
+            full_command = ["pkexec"] + command_parts
+            GLib.idle_add(self.log, f"Executing command: {' '.join(full_command)}")
+            GLib.idle_add(self.progress_dialog.status_label.set_text, "Starting transaction...")
 
-                process = subprocess.Popen(
-                    full_command,
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.STDOUT,
-                    text=True,
-                    errors='ignore',
-                    env=os.environ
-                )
+            process = subprocess.Popen(
+                full_command,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.STDOUT,
+                text=True,
+                errors='ignore',
+                env=os.environ
+            )
 
-                # Read stdout line-by-line in real-time
-                for line in iter(process.stdout.readline, ''):
-                    GLib.idle_add(self._on_progress_update, line)
-
-                # Wait for the process to finish and get the return code
-                process.wait()
-                stdout, stderr = process.communicate()
-                returncode = process.returncode
-
-                # Clean up the output
-                full_output = stdout.strip() if stdout else ""
-                if stderr and stderr.strip():
-                    full_output += "\n\nError Output:\n" + stderr.strip()
-
-                # Append a footer so user always knows the result
-                if returncode == 0:
-                    full_output += "\n\n✔ Transaction completed successfully."
-                    GLib.idle_add(self._on_transaction_complete, True)
-                else:
-                    full_output += "\n\n✘ Transaction failed. Please check logs."
-                    GLib.idle_add(self._on_transaction_complete, False)
-
-                # Update dialog with full output by appending to the buffer
-                GLib.idle_add(self._append_to_log, full_output)
+            # Read stdout line-by-line in real-time
+            for line in iter(process.stdout.readline, ''):
+                GLib.idle_add(self._on_progress_update, line)
             
-            except (IOError, OSError) as e:
-                if "No such file or directory" in str(e):
-                    GLib.idle_add(self._on_transaction_complete, False, "pkexec or dnf not found. Is it installed?")
-                else:
-                    GLib.idle_add(self._on_transaction_complete, False, f"An unexpected I/O error occurred: {e}")
-            except Exception as e:
-                GLib.idle_add(self._on_transaction_complete, False, f"An unexpected error occurred: {e}")
-    # Add this new method to your class
-    def _append_to_log(self, text):
-        buffer = self.progress_dialog.output_textview.get_buffer()
-        end_iter = buffer.get_end_iter()
-        buffer.insert(end_iter, text)
-    
-        # Force the scrollbar to the end
-        adj = self.progress_dialog.output_textview.get_vadjustment()
-        adj.set_value(adj.get_upper() - adj.get_page_size())
+            # Wait for the process to finish and get the return code
+            process.wait()
+            stdout, stderr = process.communicate()
+            returncode = process.returncode
+            
+            # Clean up the output to be displayed
+            full_output = stdout.strip()
+            if stderr.strip():
+                full_output += "\n\nError Output:\n" + stderr.strip()
+
+            GLib.idle_add(self.progress_dialog.output_textview.get_buffer().set_text, full_output)
+            
+            if returncode == 0:
+                GLib.idle_add(self._on_transaction_complete, True)
+            else:
+                GLib.idle_add(self._on_transaction_complete, False)
+                
+        except FileNotFoundError:
+            GLib.idle_add(self._on_transaction_complete, False, "pkexec or dnf not found. Is it installed?")
+        except Exception as e:
+            GLib.idle_add(self._on_transaction_complete, False, f"An unexpected error occurred: {e}")
 
     def _on_progress_update(self, line):
         # This function updates the progress dialog from the background thread
@@ -1411,7 +1245,7 @@ class PackageApp(Gtk.ApplicationWindow):
             self.progress_dialog.status_label.set_text("Transaction complete.")
         
     def _on_transaction_complete(self, success, error_message=""):
-        # Called when the transaction thread is finished
+        # This function is called when the transaction thread is finished
         if success:
             self.progress_dialog.set_title("Success")
             self.progress_dialog.status_label.set_text("Operation completed successfully.")
@@ -1423,11 +1257,8 @@ class PackageApp(Gtk.ApplicationWindow):
             self.progress_dialog.set_title("Error")
             self.progress_dialog.status_label.set_text("Operation failed.")
             self.log("Transaction failed.")
-
             if error_message:
                 self.log(error_message)
-                # Show a scrollable popup with the error
-                self.show_transaction_error(error_message)
 
         # Allow the user to close the dialog
         self.progress_dialog.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
@@ -1724,7 +1555,7 @@ class PackageApp(Gtk.ApplicationWindow):
             self.log(f"Error: Failed to save preferences to {CONFIG_FILE}. Error: {e}")
 
     def on_preferences_button_clicked(self, widget, data=None):
-        PreferencesWindow(self, self.preferences)
+        self.PreferencesWindow(self, self.preferences)
         
     def on_history_button_clicked(self, widget, data=None):
         self.HistoryDialog(self)
@@ -1732,7 +1563,7 @@ class PackageApp(Gtk.ApplicationWindow):
     def on_about_button_clicked(self, widget):
         about_dialog = Gtk.AboutDialog()
         about_dialog.set_program_name("DNF Package Manager")
-        about_dialog.set_version("1.13")
+        about_dialog.set_version("1.1")
         about_dialog.set_copyright("https://www.pclinuxos.com/\n\n© 2025 PCLinuxOS Community")
         about_dialog.set_comments("A simple and user-friendly GUI for DNF to manage packages.")
         about_dialog.set_authors(["Upgreyed, Texstar"])
@@ -1848,18 +1679,13 @@ class PackageApp(Gtk.ApplicationWindow):
         timestamp = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
         formatted_message = f"[{timestamp}] {message}"
         print(f"[GUI Log] {formatted_message}")
-
         def _add_log_message():
             buffer = self.log_textview.get_buffer()
+            buffer.insert(buffer.get_end_iter(), formatted_message + "\n")
             end_iter = buffer.get_end_iter()
-            buffer.insert(end_iter, formatted_message + "\n")
-
-            # Scroll to the bottom
-            self.log_textview.scroll_to_iter(buffer.get_end_iter(), 0.0, False, 0, 0)
-
-            # Ensure the textview remains scrollable
-            self.log_textview.set_sensitive(True)
-
+            mark = buffer.create_mark(None, end_iter, False)
+            self.log_textview.scroll_to_mark(mark, 0.0, True, 0.0, 1.0)
+            buffer.delete_mark(mark)
         GLib.idle_add(_add_log_message)
 
     def filter_packages(self, model, iter, data):
